==> igniteui-react-core-16.6.5.tgz: package/ES5/LiteralFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { LiteralFilterExpressionDescription } from "./LiteralFilterExpressionDescription";
var LiteralFilterExpressionDescriptionMetadata = /** @class */ (function (_super) {
    tslib_1.__extends(LiteralFilterExpressionDescriptionMetadata, _super);
    function LiteralFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LiteralFilterExpressionDescriptionMetadata.b = function (a) {
        if (LiteralFilterExpressionDescriptionMetadata.a == null) {
            LiteralFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LiteralFilterExpressionDescriptionMetadata.c(a, LiteralFilterExpressionDescriptionMetadata.a);
        }
    };
    LiteralFilterExpressionDescriptionMetadata.c = function (a, b) {
        FilterExpressionDescriptionMetadata.c(a, b);
        b.item("LiteralValueRef", "(w:LiteralValue)DataRef");
        b.item("LeaveUnquoted", "Boolean");
    };
    LiteralFilterExpressionDescriptionMetadata.d = function (a) {
        LiteralFilterExpressionDescriptionMetadata.b(a);
        a.n("LiteralFilterExpression", function () { return new LiteralFilterExpressionDescription(); });
        a.m("LiteralFilterExpression", LiteralFilterExpressionDescriptionMetadata.a);
    };
    LiteralFilterExpressionDescriptionMetadata.$t = markType(LiteralFilterExpressionDescriptionMetadata, 'LiteralFilterExpressionDescriptionMetadata');
    LiteralFilterExpressionDescriptionMetadata.a = null;
    return LiteralFilterExpressionDescriptionMetadata;
}(Base));
export { LiteralFilterExpressionDescriptionMetadata };

==> igniteui-react-core-16.11.0.tgz: package/ES5/LiteralFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { LiteralFilterExpressionDescription } from "./LiteralFilterExpressionDescription";
/**
 * @hidden
 */
var LiteralFilterExpressionDescriptionMetadata = /** @class */ (function (_super) {
    tslib_1.__extends(LiteralFilterExpressionDescriptionMetadata, _super);
    function LiteralFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LiteralFilterExpressionDescriptionMetadata.b = function (a) {
        if (LiteralFilterExpressionDescriptionMetadata.a == null) {
            LiteralFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LiteralFilterExpressionDescriptionMetadata.c(a, LiteralFilterExpressionDescriptionMetadata.a);
        }
    };
    LiteralFilterExpressionDescriptionMetadata.c = function (a, b) {
        FilterExpressionDescriptionMetadata.c(a, b);
        b.item("LiteralValueRef", "(w:LiteralValue,wf:LiteralValue)DataRef");
        b.item("LeaveUnquoted", "Boolean");
    };
    LiteralFilterExpressionDescriptionMetadata.d = function (a) {
        LiteralFilterExpressionDescriptionMetadata.b(a);
        a.n("LiteralFilterExpression", function () { return new LiteralFilterExpressionDescription(); });
        a.m("LiteralFilterExpression", LiteralFilterExpressionDescriptionMetadata.a);
    };
    LiteralFilterExpressionDescriptionMetadata.$t = markType(LiteralFilterExpressionDescriptionMetadata, 'LiteralFilterExpressionDescriptionMetadata');
    LiteralFilterExpressionDescriptionMetadata.a = null;
    return LiteralFilterExpressionDescriptionMetadata;
}(Base));
export { LiteralFilterExpressionDescriptionMetadata };
